// @(#)root/test:$Name:  $:$Id: MyEvent.cxx,v 1.27 2004/01/25 20:33:32 brun Exp $
// Author: Rene Brun   19/08/96
////////////////////////////////////////////////////////////////////////
//
//                       Event and Track classes
//                       =======================
//
////////////////////////////////////////////////////////////////////////


#include "TRandom.h"
#include "TObject.h"
#include "TDirectory.h"
#include "TProcessID.h"
#include "TClonesArray.h"

#include "MyEvent.h"

TClonesArray *MyEvent::fgTracks = 0;
Int_t fNtrack = 0;
using namespace std;

ClassImp(MyTrack)
ClassImp(MyEventHeader)
ClassImp(MyEvent)

//______________________________________________________________________________
MyEvent::MyEvent()
{
   // Create an Event object.
   // When the constructor is invoked for the first time, the class static
   // variable fgTracks is 0 and the TClonesArray fgTracks is created.

      if (!fgTracks) fgTracks = new TClonesArray("MyTrack", 1000);
      Tracks = fgTracks;
      fNtrack = 0;
}

//______________________________________________________________________________
MyEvent::~MyEvent()
{
   Clear();
}

//______________________________________________________________________________

MyTrack* MyEvent::AddTrack(Int_t Ido, Int_t Idpo, Int_t Rego, Int_t Zo, Int_t Ao, Double_t Masao, Double_t Eco, Double_t Impo, Double_t Thetao, Double_t Phio, Double_t xo, Double_t yo, Double_t zo, Double_t Timpo, Int_t Nevto)
{
   // Add a new track to the list of tracks for this event.
   // To avoid calling the very time consuming operator new for each track,
   // the standard but not well know C++ operator "new with placement"
   // is called. If tracks[i] is 0, a new Track object will be created
   // otherwise the previous Track[i] will be overwritten.


#if ROOT_VERSION_CODE >= ROOT_VERSION(5,32,0)
   MyTrack *track = (MyTrack*)Tracks->ConstructedAt(fNtrack++);
//   cout<<"[I] I am in MyEvent::AddTrack() ... ROOT_Version > 5.32"<<endl;
   track->Set(Ido,Idpo,Rego,Zo,Ao,Masao,Eco,Impo,Thetao,Phio,xo,yo,zo,Timpo,Nevto);
#else
   TClonesArray &tracks = *Tracks;
   MyTrack *track = new(tracks[fNtrack++]) MyTrack(Ido, Idpo, Rego, Zo, Ao, Masao, Eco, Impo, Thetao, Phio, xo, yo, zo, Timpo, Nevto);
#endif

//   cout<<"[I] Added Track Id = "<<Ido<<"; Idp = "<<Idpo<<"; Reg = "<<Rego<<"; Masa = "<<Masao<<endl;

  return track;
}


void MyEvent::SetHeader(Int_t i, Int_t tracks,  Int_t date)
  {

     EvtHdr.Set(i, tracks, date);
  }

//______________________________________________________________________________
void MyEvent::Clear(Option_t * /*option*/)
{
    fNtrack = 0;
    Tracks->Clear("C"); //will also call Track::Clear
//    cout<<"[Info] I just cleared Tracks ..."<<endl; 
}

//______________________________________________________________________________
void MyEvent::Reset(Option_t * /*option*/)
{
// Static function to reset all static objects for this event
    delete fgTracks; fgTracks = 0;
}


// Standard constructor
MyTrack::MyTrack ( Int_t Ido, Int_t Idpo, Int_t Rego, Int_t Zo, Int_t Ao,
               Double_t Masao, Double_t Eco, Double_t Impo, Double_t Thetao, Double_t Phio, Double_t xo, Double_t yo, Double_t zo, Double_t Timpo, 
               Int_t Nevto) : TObject()
  {
//    cout<<"[I] I am in Track::Track(Int_t, Int_t, ...)"<<endl;
    Id = Ido;
    Idp = Idpo;
    Reg = Rego;
    Z = Zo;
    A = Ao;
    Masa = Masao;
    Ec = Eco;
    Imp = Impo;
    Theta = Thetao;
    Phi = Phio;
    x = xo;
    y = yo;
    z = zo;
    Time = Timpo;
    Nevt = Nevto;
  }

MyTrack::MyTrack(const MyTrack &orig) : TObject(orig)
  {
   // Copy a track object
//   cout<<"[I] I am in Track::Track(const Track &orig)"<<endl;      
   Id = orig.Id;
   Idp= orig.Idp;
   Reg= orig.Reg;
   Z  = orig.Z;
   A  = orig.A;
   Masa= orig.Masa;
   Ec = orig.Ec;
   Imp = orig.Imp;
   Theta = orig.Theta;
   Phi = orig.Phi;
   x = orig.x;
   y = orig.y;
   z = orig.z;
   Time = orig.Time;
   Nevt = orig.Nevt;
  }

  
MyTrack &MyTrack::operator=(const MyTrack &orig)
  {
   // Copy a track object
//   cout<<"[I] I am in Track::Track(const Track &orig)"<<endl;    
   TObject::operator=(orig);
   Id = orig.Id;
   Idp= orig.Idp;
   Reg= orig.Reg;
   Z  = orig.Z;
   A  = orig.A;
   Masa= orig.Masa;
   Ec = orig.Ec;
   Imp = orig.Imp;
   Theta = orig.Theta;
   Phi = orig.Phi;
   x = orig.x;
   y = orig.y;
   z = orig.z;
   Time = orig.Time;
   Nevt = orig.Nevt;
   return *this;
  }

void MyTrack::Set(Int_t Ido, Int_t Idpo, Int_t Rego, Int_t Zo, Int_t Ao, Double_t Masao, Double_t Eco, Double_t Impo, Double_t Thetao, Double_t Phio, Double_t xo, Double_t yo, Double_t zo, Double_t Timpo, Int_t Nevto)
{
//    cout<<"[I] I am in Track::Set(Int_t, Int_t, ...)"<<endl;
    Id = Ido;
    Idp = Idpo;
    Reg = Rego;
    Z = Zo;
    A = Ao;
    Masa = Masao;
    Ec = Eco;
    Imp = Impo;
    Theta = Thetao;
    Phi = Phio;
    x = xo;
    y = yo;
    z = zo;
    Time = Timpo;
    Nevt = Nevto;
}

//______________________________________________________________________________

void MyTrack::Clear(Option_t * /*option*/)
{

   TObject::Clear();
//   cout<<"[Info] I just cleared TObject from Track::Clear()"<<endl; 
}
