#ifndef ROOT_Event
#define ROOT_Event

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// Event                                                                //
//                                                                      //
// Description of the event and track parameters                        //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#include "TObject.h"
#include "TNamed.h"
#include "TFile.h"
#include "TTree.h"
#include "TClonesArray.h"
#include "TMath.h"

#include <iostream>
#include <stdio.h>

using namespace std;

class TClonesArray;

class MyTrack : public TObject {

private:
   Int_t          Id;
   Int_t          Idp;
   Int_t          Reg;              //Number of track segments
   Int_t          Z;
   Int_t          A;
   Double_t       Masa;
   Double_t       Ec;
   Double_t       Imp;
   Double_t       Theta;
   Double_t       Phi;
   Double_t       x;
   Double_t       y;
   Double_t       z;
   Double_t       Time;
   Int_t          Nevt;

public:
   MyTrack() { };
   MyTrack(const MyTrack& orig);
   MyTrack(Int_t Ido, Int_t Idpo, Int_t Rego, Int_t Zo, Int_t Ao, Double_t Masao, Double_t Eco, Double_t Impo, Double_t Thetao, Double_t Phio, Double_t xo, Double_t yo, Double_t zo, Double_t Timpo, Int_t Nevto);
   virtual ~MyTrack() {Clear();}
   MyTrack &operator=(const MyTrack &orig);

   void Set(Int_t Ido, Int_t Idpo, Int_t Rego, Int_t Zo, Int_t Ao, Double_t Masao, Double_t Eco, Double_t Impo, Double_t Thetao, Double_t Phio, Double_t xo, Double_t yo, Double_t zo, Double_t Timpo, Int_t Nevto);
// -------------------------------------------------------------------------------------------------------------------------------   
   void          Clear(Option_t *option="");
// -------------------------------------------------------------------------------------------------------------------------------   
   Float_t       GetId() const { return Id; }
   Float_t       GetIdp() const { return Idp; }
   Float_t       GetReg() const { return Reg; }
   Float_t       GetZ() const { return Z; }
   Float_t       GetA() const { return A; }
   Float_t       GetMass() const { return Masa; }
   Float_t       GetEc() const { return Ec; }
   Float_t       GetImp() const { return Imp; }
   Float_t       GetTheta() const { return Theta; }
   Float_t       GetPhi() const { return Phi; }
   Float_t       Getx()  const { return x; }
   Float_t       Gety() const { return y; }
   Float_t       Getz()  const { return z; }
   Float_t       GetTime() const { return Time; }
   Float_t       GetNevt()  const { return Nevt; }

   ClassDef(MyTrack,2)  //A track segment
};


class MyEventHeader : public TNamed {

private:
   Int_t   NrEvt;
   Int_t   DataEvt;
   Int_t   NrTracks;
   

public:
   MyEventHeader() { };
   virtual ~MyEventHeader() { }
   void   Set(Int_t i, Int_t tracks, Int_t d) { NrEvt = i; NrTracks = tracks; DataEvt = d; }
   Int_t  GetEvtNum() const { return NrEvt; }
   Int_t  GetEvtTracks() const {return NrTracks;}
   Int_t  GetDate() const { return DataEvt; }

   ClassDef(MyEventHeader,1)  //Event Header
};

class MyEvent : public TObject {

private:
   MyEventHeader    EvtHdr;
   TClonesArray   *Tracks;

   static TClonesArray *fgTracks;

   MyEvent(const MyEvent&) = delete;
   MyEvent &operator=(const MyEvent&) = delete;
   
public:

   MyEvent();
   virtual ~MyEvent();
   void   Clear(Option_t *option ="");
   static void   Reset(Option_t *option ="");
   void   SetHeader(Int_t i, Int_t tracks, Int_t date);
   MyTrack  *AddTrack(Int_t Id, Int_t Idp, Int_t Reg, Int_t Z, Int_t A, Double_t Masa, Double_t Ec, Double_t Imp, Double_t Theta, Double_t Phi, Double_t x, Double_t y, Double_t z, Double_t Timp, Int_t NrEvt);

//   void          Build(Int_t ev, Int_t arg5=600);
//   void          SetNseg(Int_t n) { fNseg = n; }
//   void          SetNtrack(Int_t n) { fNtrack = n; }
//   void          SetFlag(UInt_t f) { fFlag = f; }
//   Float_t       GetClosestDistance(Int_t i) {return fClosestDistance[i];}
//   char         *GetType() {return fType;}
//   Int_t         GetNtrack() const { return fNtrack; }
//   Int_t         GetNseg() const { return fNseg; }
//   Int_t         GetNvertex() const { return fNvertex; }
//   UInt_t        GetFlag() const { return fFlag; }
   TClonesArray *GetTracks() const {return Tracks;}
   MyEventHeader  *GetHeader() { return &EvtHdr; }

   ClassDef(MyEvent,1)  //Event structure
};

#endif
